#include <config.h>

#include "fsview.h"

static GtkWidget *table;
static GtkWidget *nLabel;

void
sysview_handler (GtkNotebook *notebook, GtkNotebookPage *page, GTopPageSignal s)
{
	/* check if it is for me */
	if (page->child == table) {

		switch (s) {

		case GTOP_PAGE_ENTER:

			gnome_app_menu_show (GNOME_APP(window),
					     GTOP_MENU_SYSTEM, -1);
			break;

		case GTOP_PAGE_LEAVE:

			gnome_app_menu_hide (GNOME_APP(window),
					     GTOP_MENU_SYSTEM, -1);
			break;
		}
	}
}

void *
addSystemView () {
	
	nLabel = gtk_label_new (_("System"));
	table =  gtk_table_new (10, 10, FALSE);

	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), table, nLabel);

	gtk_widget_show (nLabel);
	gtk_widget_show (table);

	return sysview_handler;
}
